@@ -1,7 +1,7 @@
 package Sah::Schema::perl::modnames;
 
 our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.022'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 our $schema = [array => {
     summary => 'Perl module names',
@@ -18,9 +18,8 @@ and it will be expanded to e.g.:
 
     ["Module::Patch", "Module::Path", "Module::Pluggable"]
 
-The wildcard syntax supports jokers (`?`, '*`) and brackets (`[abc]`). See the
-`unix` type of wildcard in <pm:Regexp::Wildcards>, which this coercion rule
-uses.
+The wildcard syntax supports jokers (`?`, `*`, `**`), brackets (`[abc]`), and
+braces (`{one,two}`).
 
 _
     of => ["perl::modname", {req=>1}, {}],
@@ -49,7 +48,7 @@ Sah::Schema::perl::modnames - Perl module names
 
 =head1 VERSION
 
-This document describes version 0.022 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
+This document describes version 0.023 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
 
 =head1 DESCRIPTION
 
@@ -64,9 +63,8 @@ and it will be expanded to e.g.:
 
  ["Module::Patch", "Module::Path", "Module::Pluggable"]
 
-The wildcard syntax supports jokers (C<?>, '*C<) and brackets (>[abc]C<). See the
->unix` type of wildcard in L<Regexp::Wildcards>, which this coercion rule
-uses.
+The wildcard syntax supports jokers (C<?>, C<*>, C<**>), brackets (C<[abc]>), and
+braces (C<{one,two}>).
 
 =head1 HOMEPAGE
 
